##  Requires/Required by Relations
The Requires / Required By relation type in SAP LeanIX is used to create further logical dependencies within one fact sheet type or between fact sheet types.
  * Within the same fact sheet type: A server requires an OS (operating system). These are both IT components, but only the server is directly linked to the application. Using logical n:m dependencies, however, the “Obsolescence: Aggregated Risk” views allow you to extract the information that the OS is also linked to, albeit indirectly, through the server. However, you cannot see the indirect connection in the obsolescence risk views of the application matrix and landscape reports.
  * Between fact sheet types: For documentation purposes, showing the dependencies between fact sheets of different fact sheet types (e.g., data object to process) might be helpful. This relation cannot be visualized in standard reports and is only available on the fact sheets and in the table view.
